==> xz-5.2.7-i586-1.txz: install/doinst.sh <==
( cd lib ; rm -rf liblzma.so.5 )
( cd lib ; ln -sf liblzma.so.5.2.7 liblzma.so.5 )
( cd usr/bin ; rm -rf lzcat )
( cd usr/bin ; ln -sf xz lzcat )
( cd usr/bin ; rm -rf lzcmp )
( cd usr/bin ; ln -sf xzdiff lzcmp )
( cd usr/bin ; rm -rf lzdiff )
( cd usr/bin ; ln -sf xzdiff lzdiff )
( cd usr/bin ; rm -rf lzegrep )
( cd usr/bin ; ln -sf xzgrep lzegrep )
( cd usr/bin ; rm -rf lzfgrep )
( cd usr/bin ; ln -sf xzgrep lzfgrep )
( cd usr/bin ; rm -rf lzgrep )
( cd usr/bin ; ln -sf xzgrep lzgrep )
( cd usr/bin ; rm -rf lzless )
( cd usr/bin ; ln -sf xzless lzless )
( cd usr/bin ; rm -rf lzma )
( cd usr/bin ; ln -sf xz lzma )
( cd usr/bin ; rm -rf lzmore )
( cd usr/bin ; ln -sf xzmore lzmore )
( cd usr/bin ; rm -rf unlzma )
( cd usr/bin ; ln -sf xz unlzma )
( cd usr/bin ; rm -rf unxz )
( cd usr/bin ; ln -sf xz unxz )
( cd usr/bin ; rm -rf xz )
( cd usr/bin ; ln -sf ../../bin/xz xz )
( cd usr/bin ; rm -rf xzcat )
( cd usr/bin ; ln -sf xz xzcat )
( cd usr/bin ; rm -rf xzcmp )
( cd usr/bin ; ln -sf xzdiff xzcmp )
( cd usr/bin ; rm -rf xzegrep )
( cd usr/bin ; ln -sf xzgrep xzegrep )
( cd usr/bin ; rm -rf xzfgrep )
( cd usr/bin ; ln -sf xzgrep xzfgrep )
( cd usr/lib ; rm -rf liblzma.so )
( cd usr/lib ; ln -sf ../../lib/liblzma.so.5 liblzma.so )
( cd usr/man/de/man1 ; rm -rf lzcat.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz lzcat.1.gz )
( cd usr/man/de/man1 ; rm -rf lzcmp.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdiff.1.gz lzcmp.1.gz )
( cd usr/man/de/man1 ; rm -rf lzdiff.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdiff.1.gz lzdiff.1.gz )
( cd usr/man/de/man1 ; rm -rf lzless.1.gz )
( cd usr/man/de/man1 ; ln -sf xzless.1.gz lzless.1.gz )
( cd usr/man/de/man1 ; rm -rf lzma.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz lzma.1.gz )
( cd usr/man/de/man1 ; rm -rf lzmadec.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdec.1.gz lzmadec.1.gz )
( cd usr/man/de/man1 ; rm -rf lzmore.1.gz )
( cd usr/man/de/man1 ; ln -sf xzmore.1.gz lzmore.1.gz )
( cd usr/man/de/man1 ; rm -rf unlzma.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz unlzma.1.gz )
( cd usr/man/de/man1 ; rm -rf unxz.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz unxz.1.gz )
( cd usr/man/de/man1 ; rm -rf xzcat.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz xzcat.1.gz )
( cd usr/man/de/man1 ; rm -rf xzcmp.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdiff.1.gz xzcmp.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf lzcat.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xz.1.gz lzcat.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf lzcmp.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xzdiff.1.gz lzcmp.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf lzdiff.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xzdiff.1.gz lzdiff.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf lzless.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xzless.1.gz lzless.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf lzma.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xz.1.gz lzma.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf lzmadec.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xzdec.1.gz lzmadec.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf lzmore.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xzmore.1.gz lzmore.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf unlzma.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xz.1.gz unlzma.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf unxz.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xz.1.gz unxz.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf xzcat.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xz.1.gz xzcat.1.gz )
( cd usr/man/fr_FR/man1 ; rm -rf xzcmp.1.gz )
( cd usr/man/fr_FR/man1 ; ln -sf xzdiff.1.gz xzcmp.1.gz )
( cd usr/man/man1 ; rm -rf lzcat.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz lzcat.1.gz )
( cd usr/man/man1 ; rm -rf lzcmp.1.gz )
( cd usr/man/man1 ; ln -sf xzdiff.1.gz lzcmp.1.gz )
( cd usr/man/man1 ; rm -rf lzdiff.1.gz )
( cd usr/man/man1 ; ln -sf xzdiff.1.gz lzdiff.1.gz )
( cd usr/man/man1 ; rm -rf lzegrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz lzegrep.1.gz )
( cd usr/man/man1 ; rm -rf lzfgrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz lzfgrep.1.gz )
( cd usr/man/man1 ; rm -rf lzgrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz lzgrep.1.gz )
( cd usr/man/man1 ; rm -rf lzless.1.gz )
( cd usr/man/man1 ; ln -sf xzless.1.gz lzless.1.gz )
( cd usr/man/man1 ; rm -rf lzma.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz lzma.1.gz )
( cd usr/man/man1 ; rm -rf lzmadec.1.gz )
( cd usr/man/man1 ; ln -sf xzdec.1.gz lzmadec.1.gz )
( cd usr/man/man1 ; rm -rf lzmore.1.gz )
( cd usr/man/man1 ; ln -sf xzmore.1.gz lzmore.1.gz )
( cd usr/man/man1 ; rm -rf unlzma.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz unlzma.1.gz )
( cd usr/man/man1 ; rm -rf unxz.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz unxz.1.gz )
( cd usr/man/man1 ; rm -rf xzcat.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz xzcat.1.gz )
( cd usr/man/man1 ; rm -rf xzcmp.1.gz )
( cd usr/man/man1 ; ln -sf xzdiff.1.gz xzcmp.1.gz )
( cd usr/man/man1 ; rm -rf xzegrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz xzegrep.1.gz )
( cd usr/man/man1 ; rm -rf xzfgrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz xzfgrep.1.gz )

==> xz-5.2.8-i586-1.txz: install/doinst.sh <==
( cd lib ; rm -rf liblzma.so.5 )
( cd lib ; ln -sf liblzma.so.5.2.8 liblzma.so.5 )
( cd usr/bin ; rm -rf lzcat )
( cd usr/bin ; ln -sf xz lzcat )
( cd usr/bin ; rm -rf lzcmp )
( cd usr/bin ; ln -sf xzdiff lzcmp )
( cd usr/bin ; rm -rf lzdiff )
( cd usr/bin ; ln -sf xzdiff lzdiff )
( cd usr/bin ; rm -rf lzegrep )
( cd usr/bin ; ln -sf xzgrep lzegrep )
( cd usr/bin ; rm -rf lzfgrep )
( cd usr/bin ; ln -sf xzgrep lzfgrep )
( cd usr/bin ; rm -rf lzgrep )
( cd usr/bin ; ln -sf xzgrep lzgrep )
( cd usr/bin ; rm -rf lzless )
( cd usr/bin ; ln -sf xzless lzless )
( cd usr/bin ; rm -rf lzma )
( cd usr/bin ; ln -sf xz lzma )
( cd usr/bin ; rm -rf lzmore )
( cd usr/bin ; ln -sf xzmore lzmore )
( cd usr/bin ; rm -rf unlzma )
( cd usr/bin ; ln -sf xz unlzma )
( cd usr/bin ; rm -rf unxz )
( cd usr/bin ; ln -sf xz unxz )
( cd usr/bin ; rm -rf xz )
( cd usr/bin ; ln -sf ../../bin/xz xz )
( cd usr/bin ; rm -rf xzcat )
( cd usr/bin ; ln -sf xz xzcat )
( cd usr/bin ; rm -rf xzcmp )
( cd usr/bin ; ln -sf xzdiff xzcmp )
( cd usr/bin ; rm -rf xzegrep )
( cd usr/bin ; ln -sf xzgrep xzegrep )
( cd usr/bin ; rm -rf xzfgrep )
( cd usr/bin ; ln -sf xzgrep xzfgrep )
( cd usr/lib ; rm -rf liblzma.so )
( cd usr/lib ; ln -sf ../../lib/liblzma.so.5 liblzma.so )
( cd usr/man/de/man1 ; rm -rf lzcat.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz lzcat.1.gz )
( cd usr/man/de/man1 ; rm -rf lzcmp.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdiff.1.gz lzcmp.1.gz )
( cd usr/man/de/man1 ; rm -rf lzdiff.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdiff.1.gz lzdiff.1.gz )
( cd usr/man/de/man1 ; rm -rf lzless.1.gz )
( cd usr/man/de/man1 ; ln -sf xzless.1.gz lzless.1.gz )
( cd usr/man/de/man1 ; rm -rf lzma.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz lzma.1.gz )
( cd usr/man/de/man1 ; rm -rf lzmadec.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdec.1.gz lzmadec.1.gz )
( cd usr/man/de/man1 ; rm -rf lzmore.1.gz )
( cd usr/man/de/man1 ; ln -sf xzmore.1.gz lzmore.1.gz )
( cd usr/man/de/man1 ; rm -rf unlzma.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz unlzma.1.gz )
( cd usr/man/de/man1 ; rm -rf unxz.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz unxz.1.gz )
( cd usr/man/de/man1 ; rm -rf xzcat.1.gz )
( cd usr/man/de/man1 ; ln -sf xz.1.gz xzcat.1.gz )
( cd usr/man/de/man1 ; rm -rf xzcmp.1.gz )
( cd usr/man/de/man1 ; ln -sf xzdiff.1.gz xzcmp.1.gz )
( cd usr/man/fr/man1 ; rm -rf lzcat.1.gz )
( cd usr/man/fr/man1 ; ln -sf xz.1.gz lzcat.1.gz )
( cd usr/man/fr/man1 ; rm -rf lzcmp.1.gz )
( cd usr/man/fr/man1 ; ln -sf xzdiff.1.gz lzcmp.1.gz )
( cd usr/man/fr/man1 ; rm -rf lzdiff.1.gz )
( cd usr/man/fr/man1 ; ln -sf xzdiff.1.gz lzdiff.1.gz )
( cd usr/man/fr/man1 ; rm -rf lzless.1.gz )
( cd usr/man/fr/man1 ; ln -sf xzless.1.gz lzless.1.gz )
( cd usr/man/fr/man1 ; rm -rf lzma.1.gz )
( cd usr/man/fr/man1 ; ln -sf xz.1.gz lzma.1.gz )
( cd usr/man/fr/man1 ; rm -rf lzmadec.1.gz )
( cd usr/man/fr/man1 ; ln -sf xzdec.1.gz lzmadec.1.gz )
( cd usr/man/fr/man1 ; rm -rf lzmore.1.gz )
( cd usr/man/fr/man1 ; ln -sf xzmore.1.gz lzmore.1.gz )
( cd usr/man/fr/man1 ; rm -rf unlzma.1.gz )
( cd usr/man/fr/man1 ; ln -sf xz.1.gz unlzma.1.gz )
( cd usr/man/fr/man1 ; rm -rf unxz.1.gz )
( cd usr/man/fr/man1 ; ln -sf xz.1.gz unxz.1.gz )
( cd usr/man/fr/man1 ; rm -rf xzcat.1.gz )
( cd usr/man/fr/man1 ; ln -sf xz.1.gz xzcat.1.gz )
( cd usr/man/fr/man1 ; rm -rf xzcmp.1.gz )
( cd usr/man/fr/man1 ; ln -sf xzdiff.1.gz xzcmp.1.gz )
( cd usr/man/man1 ; rm -rf lzcat.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz lzcat.1.gz )
( cd usr/man/man1 ; rm -rf lzcmp.1.gz )
( cd usr/man/man1 ; ln -sf xzdiff.1.gz lzcmp.1.gz )
( cd usr/man/man1 ; rm -rf lzdiff.1.gz )
( cd usr/man/man1 ; ln -sf xzdiff.1.gz lzdiff.1.gz )
( cd usr/man/man1 ; rm -rf lzegrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz lzegrep.1.gz )
( cd usr/man/man1 ; rm -rf lzfgrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz lzfgrep.1.gz )
( cd usr/man/man1 ; rm -rf lzgrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz lzgrep.1.gz )
( cd usr/man/man1 ; rm -rf lzless.1.gz )
( cd usr/man/man1 ; ln -sf xzless.1.gz lzless.1.gz )
( cd usr/man/man1 ; rm -rf lzma.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz lzma.1.gz )
( cd usr/man/man1 ; rm -rf lzmadec.1.gz )
( cd usr/man/man1 ; ln -sf xzdec.1.gz lzmadec.1.gz )
( cd usr/man/man1 ; rm -rf lzmore.1.gz )
( cd usr/man/man1 ; ln -sf xzmore.1.gz lzmore.1.gz )
( cd usr/man/man1 ; rm -rf unlzma.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz unlzma.1.gz )
( cd usr/man/man1 ; rm -rf unxz.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz unxz.1.gz )
( cd usr/man/man1 ; rm -rf xzcat.1.gz )
( cd usr/man/man1 ; ln -sf xz.1.gz xzcat.1.gz )
( cd usr/man/man1 ; rm -rf xzcmp.1.gz )
( cd usr/man/man1 ; ln -sf xzdiff.1.gz xzcmp.1.gz )
( cd usr/man/man1 ; rm -rf xzegrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz xzegrep.1.gz )
( cd usr/man/man1 ; rm -rf xzfgrep.1.gz )
( cd usr/man/man1 ; ln -sf xzgrep.1.gz xzfgrep.1.gz )
